@@ -26,7 +26,8 @@ if args.end_date is None and args.start_date is None:
     args.start_date = str(today - timedelta(days=1))
     args.end_date = str(today)
 
-if not args.url or not args.usr or not args.pwd or not args.dataset_id:
+if not args.url or not args.usr or not args.pwd\
+        or not args.dataset_id or not args.chart_id:
     raise Exception("Missing some information")
 
 # initialize spyglass
@@ -34,10 +35,10 @@ spyglass = Spyglass(args.url, args.usr, args.pwd, args.dataset_id)
 
 # tigger the command and get the data
 for data in spyglass.streaming_cmd('chart',
-                                   [args.chart_id],
-                                   {'stream': None,
-                                    'unlimited': None,
-                                    'json': None,
-                                    'start_date': args.start_date,
-                                    'end_date': args.end_date}):
+                                   args.chart_id,
+                                   stream=None,
+                                   unlimited=None,
+                                   json=None,
+                                   start_date=None,
+                                   end_date=args.end_date):
     print data
